@@ -1,11 +1,13 @@
-'''A module that reads something from somewhere
+"""A module that reads something from somewhere
 
 Author(s):
     Carl Anderson (carl.anderson@weightwatchers.com)
 
-'''
+"""
 from primrose.base.node import AbstractNode
 
+
 class AbstractReader(AbstractNode):
     """read some data from somewhere"""
+
     pass
