@@ -1,9 +1,9 @@
 from primrose.base.node import AbstractNode
 
+
 class TestExtNode(AbstractNode):
-    
     def necessary_config(self, node_config):
-        return ([])
+        return []
 
     def run(self, data_object):
         terminate = False
